@@ -1,6 +1,6 @@
 package Net::WebSocket;
 
-our $VERSION = '0.023';
+our $VERSION = '0.03';
 
 =encoding utf-8
 
@@ -28,55 +28,58 @@ Net::WebSocket - WebSocket in Perl
     );
 
     my $ept = Net::WebSocket::Endpoint::Client->new(
-        out => $inet,
         parser => $parser,
+
+        #Include this *only* for blocking I/O. Ordinarily, control frame
+        #responses (e.g., pong, close) are queued up to be sent
+        #whenever whichever filehandle is ready to accept data.
+        #That’s for non-blocking I/O; if you’re using blocking I/O, then
+        #you can include this parameter to have those responses sent
+        #immediately.
+        out => $inet,
     );
 
     #Determine that $inet can be read from …
 
     my $msg = $ept->get_next_message();
 
-    #… or, if we timeout while waiting for $inet be ready for reading:
+    #… or, if we timeout while waiting for $inet to be ready for reading:
 
     $ept->check_heartbeat();
     exit if $ept->is_closed();
 
-=head1 ALPHA QUALITY
+=head1 BETA QUALITY
 
-This is a preliminary release. It is not meant for
-production work, but please do play with it and see how it works for you.
-Bug reports, especially with reproducible test cases, would be very welcome!
-
-Breaking changes are still a possibility here, though they should be pretty
-minor.
+This is a beta release. It should be safe for production, but there could
+still be small changes to the API. Please check the changelog before
+upgrading.
 
 =head1 DESCRIPTION
 
 This distribution provides a set of fundamental tools for communicating via
-L<https://tools.ietf.org/html/rfc6455|WebSocket>.
+L<WebSocket|https://tools.ietf.org/html/rfc6455>.
 It is only concerned with the protocol itself;
 the underlying transport mechanism is up to you: it could be a file,
-a UNIX socket, ordinary TCP/IP, or whatever.
+a UNIX socket, ordinary TCP/IP, some funky C<tie()>d object, or whatever.
 
-As a result of this “bare-bones” approach, Net::WebSocket can probably
-fit your needs; however, it won’t absolve you of the need to know the
-WebSocket protocol itself. It also doesn’t do I/O for you, but there are some
-examples
-of using L<IO::Select> for this in the distribution’s C<demo/> directory.
+Net::WebSocket also “has no opinions” about how you should do I/O or HTTP
+headers. As a result of this “bare-bones” approach, Net::WebSocket can likely
+fit your project; however, it won’t absolve you of the need to know the
+WebSocket protocol itself. There are some examples
+of how you might write complete applications (client or server)
+in the distribution’s C<demo/> directory.
 
-Net::WebSocket is not a “quick-and-cheap” WebSocket solution; rather,
-it attempts to support the protocol—and only that protocol—as
-completely, usefully, and flexibly as possible.
+Net::WebSocket is not a “quick” WebSocket solution; for that,
+check out L<Mojolicious>. Net::WebSocket’s purpose is to support anything
+that the WebSocket protocol itself can do, as lightly as possible and without
+prejudice as to how you want to do it: extensions, blocking/non-blocking I/O,
+arbitrary HTTP headers, etc. Net::WebSocket will likely require more of an
+investment up-front, but its flexibility should allow it to do anything that
+can be done with WebSocket, and much more cleanly than a more “monolithic”
+solution would likely allow.
 
 =head1 OVERVIEW
 
-WebSocket is almost “two protocols for the price of one”: the
-HTTP-derived handshake logic, then the framing logic for the actual data
-exchange. The handshake portion is complex enough, and has enough support
-from CPAN’s HTTP modules, that this distribution only provides a few basic tools
-for doing the handshake. It’s enough to get you where you need to go, but
-not much more.
-
 Here are the main modules:
 
 =head2 L<Net::WebSocket::Handshake::Server>
@@ -115,27 +118,38 @@ for sample usage.
 
 =head1 IMPLEMENTATION NOTES
 
+=head2 Handshakes
+
+WebSocket uses regular HTTP headers for its handshakes. Because there are
+many different solutions around for parsing HTTP headers, Net::WebSocket
+tries to be “agnostic” about how that’s done. The liability of this is
+that you, the library user, will need to implement some of the handshake
+logic yourself. If you’re building from the ground up that’s not a lot of
+fun, but if you’ve already got a solution in place for parsing headers then
+Net::WebSocket can fit into that quite easily.
+
 =head2 Masking
 
 As per L<the specification|https://tools.ietf.org/html/rfc6455#section-5.1>,
 client serializers “MUST” mask the data randomly, whereas server serializers
-“MUST NOT” do this. Net::WebSocket does this for you automatically
-(courtesy of L<Bytes::Random::Secure::Tiny>), but you need to distinguish
+“MUST NOT” do this. Net::WebSocket does this for you automatically,
+but you need to distinguish
 between client serializers—which mask their payloads—and server serializers,
 which don’t mask.
 
+This module used to do this with L<Bytes::Random::Secure::Tiny>, but
+that seems like overkill given that the masking is only there to accommodate
+peculiarities of certain proxies. We now just use Perl’s C<rand()>
+built-in.
+
+(You should probably use TLS if cryptographically secure masking is something
+you care about?)
+
 =head2 Text vs. Binary
 
 Recall that in some languages—like JavaScript!—the difference between
 “text” and “binary” is much more significant than for us in Perl.
 
-=head2 Parsed Frame Classes
-
-Net::WebSocket tries to be as light as possible and so, when it parses out
-a frame, at first only a base L<Net::WebSocket::Frame> implementation is
-created. An AUTOLOAD method will “upgrade” any such frame that needs the
-specific methods of its class.
-
 =head1 EXTENSION SUPPORT
 
 The WebSocket specification describes several methods of extending the
@@ -144,7 +158,8 @@ protocol, all of which Net::WebSocket supports:
 =over
 
 =item * The three reserved bits in each frame’s header.
-(See L<Net::WebSocket::Frame>.)
+(See L<Net::WebSocket::Frame>.) This is used, e.g., in the
+L<https://tools.ietf.org/html/rfc7692|permessage-deflate extension>.
 
 =item * Additional opcodes: 3-7 and 11-15. You’ll need to subclass
 L<Net::WebSocket::Frame> for this, and you will likely want to subclass
@@ -154,7 +169,8 @@ also subclass L<Net::WebSocket::Streamer>. See each of those modules for
 more information on doing this.
 
 B<THIS IS NOT WELL TESTED.> Proceed with caution, and please file bug
-reports as needed.
+reports as needed. (I personally don’t know of any applications that
+actually use this.)
 
 =item * Apportion part of the payload data for the extension. This you
 can do in your application.
@@ -173,8 +189,19 @@ can do in your application.
 
 =head1 SEE ALSO
 
+L<Mojolicious> is probably CPAN’s easiest WebSocket implementation to get
+a server up and running. If you’re building a project from scratch, you
+may find this to be a better fit for you than Net::WebSocket.
+
 L<Protocol::WebSocket> is an older module that supports
-pre-standard versions of the WebSocket protocol.
+pre-standard versions of the WebSocket protocol. It’s similar to this one
+in that it gives you just the protocol itself, but it doesn’t give you
+things like automatic ping/pong/close, classes for each message type, etc.
+
+L<Net::WebSocket::Server> implements only server behaviors and
+gives you more automation than P::WS.
+
+L<Net::WebSocket::EV> uses XS to call a C library.
 
 =head1 REPOSITORY
 
